@@ -1,6 +1,5 @@
 from os.path import exists
 import pandas as pd
-import sys
 
 class CsvUtils:
     def __init__(self,path,header,delim,dest_extension,cur_extension='.csv'):
@@ -20,7 +19,7 @@ class CsvUtils:
         """Validating if the file is in the correct format"""
         if exists(self.path) and self.path.endswith('.csv'):
             return True
-        raise FileNotFoundError("Either the path doesn't exist or the file is not a .csv")
+        raise FileNotFoundError("Either the path is incorrect or the file is not a .csv")
 
     def retur_pd(self):
         """Return pandas DF for txt files"""
@@ -29,12 +28,5 @@ class CsvUtils:
             final_header = 0
 
         if self.validate_file():
-            try:
-                df = pd.read_csv(self.path, sep=self.delim, header=final_header,engine='python',encoding_errors='replace')
-                return df
-            except UnicodeDecodeError:
-                print("Something went really wrong with the encoding of your file!")
-                raise UnicodeDecodeError
-            except Exception:
-                print("Unexpected error: ", sys.exc_info()[0])
-                raise
+            df = pd.read_csv(self.path, sep=self.delim, header=final_header,engine='python')
+            return df
\ No newline at end of file
